"use client";

import mcUtils from "mcutils-library";
import Image from "next/image";
import Link from "next/link";
import { useState } from "react";
import { toast } from "react-toastify";
import { Button } from "./ui/button";
import { Input } from "./ui/input";

export default function PlayerSearch() {
  const [playerId, setPlayerId] = useState<string | null>(null);
  const [player, setPlayer] = useState<any | null>(null);

  const handleLookup = () => {
    if (playerId === null || playerId.length <= 0) {
      toast.error("Please enter a player ID");
      return;
    }
    mcUtils.player
      .getPlayer(playerId)
      .then((response) => {
        setPlayer(response.player);
      })
      .catch(() => {
        toast.error("Player not found");
      });
  };

  const handleKeyDown = (e: any) => {
    if (e.key === "Enter") {
      handleLookup();
    }
  };

  return (
    <div className="flex flex-col items-center gap-8">
      <div className="flex items-center gap-2">
        <Input
          className="w-[200px]"
          placeholder="Player ID"
          onChange={(e) => setPlayerId(e.target.value)}
          onKeyDown={handleKeyDown}
        />
        <Button onClick={() => handleLookup()}>Lookup</Button>
      </div>

      {player && (
        <div className="bg-secondary rounded-lg p-4 min-w-[600px] max-w-full flex flex-row gap-2">
          <Image src={player.skin.parts.head} alt="The player's Head" width={150} height={150} />
          <div className="flex flex-col gap-1 mt-2">
            <p>
              Unique ID: <span className="font-bold">{player.uniqueId}</span>
            </p>
            <p>
              Name: <span className="font-bold">{player.username}</span>
            </p>
            <div className="mt-2">
              <p>Skin Parts</p>
              <div className="flex gap-2">
                {Object.keys(player.skin.parts).map((part: any, index: number) => {
                  return (
                    <p key={index}>
                      <Link className="text-primary" href={player.skin.parts[part]} target="_blank">
                        {part}
                      </Link>
                    </p>
                  );
                })}
              </div>
            </div>
          </div>
        </div>
      )}
    </div>
  );
}
