"use client";

import { cn } from "@/common/utils";
import mcUtils from "mcutils-library";
import JavaMinecraftServer from "mcutils-library/dist/types/server/javaServer";
import { ServerPlatform } from "mcutils-library/dist/types/server/platform";
import Image from "next/image";
import { useState } from "react";
import { toast } from "react-toastify";
import { Button } from "./ui/button";
import { Input } from "./ui/input";

export default function ServerSearch() {
  const [serverHostname, setServerHostname] = useState<string | null>(null);
  const [server, setServer] = useState<JavaMinecraftServer | null>(null);

  const handleLookup = () => {
    if (serverHostname === null || serverHostname.length <= 0) {
      toast.error("Please enter a server hostname");
      return;
    }
    mcUtils.server
      .getServer(ServerPlatform.Java, serverHostname)
      .then((response) => {
        setServer(response.server as JavaMinecraftServer);
      })
      .catch(() => {
        toast.error("Server not found");
      });
  };

  const handleKeyDown = (e: any) => {
    if (e.key === "Enter") {
      handleLookup();
    }
  };

  return (
    <div className="flex flex-col items-center gap-8">
      <div className="flex items-center gap-2">
        <Input
          className="w-[200px]"
          placeholder="Server Domain or IP"
          onChange={(e) => setServerHostname(e.target.value)}
          onKeyDown={handleKeyDown}
        />
        <Button onClick={() => handleLookup()}>Lookup</Button>
      </div>

      {server && (
        <div className="bg-secondary rounded-lg p-4 min-w-[460px] max-w-full flex flex-col gap-2">
          <div className="flex flex-row gap-3 items-center">
            <Image src={server.favicon.url} alt="The server's Icon" width={64} height={64} />

            <div className={cn("flex flex-col gap-2")}>
              {server.motd.html.map((line, index) => {
                return <div key={index} dangerouslySetInnerHTML={{ __html: line }} />;
              })}
            </div>
          </div>

          <div className="flex flex-col gap-1">
            <div>
              <span className="font-bold">Host:</span> {server.hostname}
            </div>
            <div>
              <span className="font-bold">Players:</span> {server.players.online}/{server.players.max}
            </div>
          </div>
        </div>
      )}
    </div>
  );
}
